==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/ServiceBusTopicEventSubscriptionDestinationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.ServiceBusTopicEventSubscriptionDestinationArgs.builder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Information about the service bus topic destination for an event subscription.
 * @property deliveryAttributeMappings Delivery attribute details.
 * @property endpointType Type of the endpoint for the event subscription destination.
 * Expected value is 'ServiceBusTopic'.
 * @property resourceId The Azure Resource Id that represents the endpoint of the Service Bus Topic destination of an event subscription.
 */
public data class ServiceBusTopicEventSubscriptionDestinationArgs(
    public val deliveryAttributeMappings:
    Output<List<Either<DynamicDeliveryAttributeMappingArgs, StaticDeliveryAttributeMappingArgs>>>? =
        null,
    public val endpointType: Output<String>,
    public val resourceId: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.ServiceBusTopicEventSubscriptionDestinationArgs> {
    override fun toJava():
        com.pulumi.azurenative.eventgrid.inputs.ServiceBusTopicEventSubscriptionDestinationArgs =
        com.pulumi.azurenative.eventgrid.inputs.ServiceBusTopicEventSubscriptionDestinationArgs.builder()
            .deliveryAttributeMappings(
                deliveryAttributeMappings?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0.let({ args0 -> args0.toJava() }) }, { args0 ->
                            args0.let({ args0 ->
                                args0.toJava()
                            })
                        })
                    })
                }),
            )
            .endpointType(endpointType.applyValue({ args0 -> args0 }))
            .resourceId(resourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ServiceBusTopicEventSubscriptionDestinationArgs].
 */
@PulumiTagMarker
public class ServiceBusTopicEventSubscriptionDestinationArgsBuilder internal constructor() {
    private var deliveryAttributeMappings:
        Output<List<Either<DynamicDeliveryAttributeMappingArgs, StaticDeliveryAttributeMappingArgs>>>? =
        null

    private var endpointType: Output<String>? = null

    private var resourceId: Output<String>? = null

    /**
     * @param value Delivery attribute details.
     */
    @JvmName("jrtjjdobplbdblwk")
    public suspend
    fun deliveryAttributeMappings(`value`: Output<List<Either<DynamicDeliveryAttributeMappingArgs, StaticDeliveryAttributeMappingArgs>>>) {
        this.deliveryAttributeMappings = value
    }

    @JvmName("twpvhccyxtgwbobp")
    public suspend fun deliveryAttributeMappings(
        vararg
        values: Output<Either<DynamicDeliveryAttributeMappingArgs, StaticDeliveryAttributeMappingArgs>>,
    ) {
        this.deliveryAttributeMappings = Output.all(values.asList())
    }

    /**
     * @param values Delivery attribute details.
     */
    @JvmName("rfpardggaoanrlod")
    public suspend
    fun deliveryAttributeMappings(values: List<Output<Either<DynamicDeliveryAttributeMappingArgs, StaticDeliveryAttributeMappingArgs>>>) {
        this.deliveryAttributeMappings = Output.all(values)
    }

    /**
     * @param value Type of the endpoint for the event subscription destination.
     * Expected value is 'ServiceBusTopic'.
     */
    @JvmName("uhuvgqngiptsshwh")
    public suspend fun endpointType(`value`: Output<String>) {
        this.endpointType = value
    }

    /**
     * @param value The Azure Resource Id that represents the endpoint of the Service Bus Topic destination of an event subscription.
     */
    @JvmName("yfamdehlryegibns")
    public suspend fun resourceId(`value`: Output<String>) {
        this.resourceId = value
    }

    /**
     * @param value Delivery attribute details.
     */
    @JvmName("jhjfgerpfaktojps")
    public suspend
    fun deliveryAttributeMappings(`value`: List<Either<DynamicDeliveryAttributeMappingArgs, StaticDeliveryAttributeMappingArgs>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deliveryAttributeMappings = mapped
    }

    /**
     * @param values Delivery attribute details.
     */
    @JvmName("vvluhnjlretcxlls")
    public suspend fun deliveryAttributeMappings(
        vararg
        values: Either<DynamicDeliveryAttributeMappingArgs, StaticDeliveryAttributeMappingArgs>,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deliveryAttributeMappings = mapped
    }

    /**
     * @param value Type of the endpoint for the event subscription destination.
     * Expected value is 'ServiceBusTopic'.
     */
    @JvmName("lxylxiudinvlcnkm")
    public suspend fun endpointType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpointType = mapped
    }

    /**
     * @param value The Azure Resource Id that represents the endpoint of the Service Bus Topic destination of an event subscription.
     */
    @JvmName("neytjinfwqmeuwue")
    public suspend fun resourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceId = mapped
    }

    internal fun build(): ServiceBusTopicEventSubscriptionDestinationArgs =
        ServiceBusTopicEventSubscriptionDestinationArgs(
            deliveryAttributeMappings = deliveryAttributeMappings,
            endpointType = endpointType ?: throw PulumiNullFieldException("endpointType"),
            resourceId = resourceId,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/ServiceBusTopicEventSubscriptionDestinationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.ServiceBusTopicEventSubscriptionDestinationArgs.builder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Information about the service bus topic destination for an event subscription.
 * @property deliveryAttributeMappings Delivery attribute details.
 * @property endpointType Type of the endpoint for the event subscription destination.
 * Expected value is 'ServiceBusTopic'.
 * @property resourceId The Azure Resource Id that represents the endpoint of the Service Bus Topic destination of an event subscription.
 */
public data class ServiceBusTopicEventSubscriptionDestinationArgs(
    public val deliveryAttributeMappings:
    Output<List<Either<DynamicDeliveryAttributeMappingArgs, StaticDeliveryAttributeMappingArgs>>>? =
        null,
    public val endpointType: Output<String>,
    public val resourceId: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.ServiceBusTopicEventSubscriptionDestinationArgs> {
    override fun toJava():
        com.pulumi.azurenative.eventgrid.inputs.ServiceBusTopicEventSubscriptionDestinationArgs =
        com.pulumi.azurenative.eventgrid.inputs.ServiceBusTopicEventSubscriptionDestinationArgs.builder()
            .deliveryAttributeMappings(
                deliveryAttributeMappings?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0.let({ args0 -> args0.toJava() }) }, { args0 ->
                            args0.let({ args0 ->
                                args0.toJava()
                            })
                        })
                    })
                }),
            )
            .endpointType(endpointType.applyValue({ args0 -> args0 }))
            .resourceId(resourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ServiceBusTopicEventSubscriptionDestinationArgs].
 */
@PulumiTagMarker
public class ServiceBusTopicEventSubscriptionDestinationArgsBuilder internal constructor() {
    private var deliveryAttributeMappings:
        Output<List<Either<DynamicDeliveryAttributeMappingArgs, StaticDeliveryAttributeMappingArgs>>>? =
        null

    private var endpointType: Output<String>? = null

    private var resourceId: Output<String>? = null

    /**
     * @param value Delivery attribute details.
     */
    @JvmName("toihjderbbokgddi")
    public suspend
    fun deliveryAttributeMappings(`value`: Output<List<Either<DynamicDeliveryAttributeMappingArgs, StaticDeliveryAttributeMappingArgs>>>) {
        this.deliveryAttributeMappings = value
    }

    @JvmName("jmwdnkvvjtfsymkv")
    public suspend fun deliveryAttributeMappings(
        vararg
        values: Output<Either<DynamicDeliveryAttributeMappingArgs, StaticDeliveryAttributeMappingArgs>>,
    ) {
        this.deliveryAttributeMappings = Output.all(values.asList())
    }

    /**
     * @param values Delivery attribute details.
     */
    @JvmName("myoxupitfqcqiran")
    public suspend
    fun deliveryAttributeMappings(values: List<Output<Either<DynamicDeliveryAttributeMappingArgs, StaticDeliveryAttributeMappingArgs>>>) {
        this.deliveryAttributeMappings = Output.all(values)
    }

    /**
     * @param value Type of the endpoint for the event subscription destination.
     * Expected value is 'ServiceBusTopic'.
     */
    @JvmName("hqukvfirsknyerjy")
    public suspend fun endpointType(`value`: Output<String>) {
        this.endpointType = value
    }

    /**
     * @param value The Azure Resource Id that represents the endpoint of the Service Bus Topic destination of an event subscription.
     */
    @JvmName("qmcelynkytqwdblo")
    public suspend fun resourceId(`value`: Output<String>) {
        this.resourceId = value
    }

    /**
     * @param value Delivery attribute details.
     */
    @JvmName("asligmtuqmtcfjoy")
    public suspend
    fun deliveryAttributeMappings(`value`: List<Either<DynamicDeliveryAttributeMappingArgs, StaticDeliveryAttributeMappingArgs>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deliveryAttributeMappings = mapped
    }

    /**
     * @param values Delivery attribute details.
     */
    @JvmName("vffsohjtumtomyma")
    public suspend fun deliveryAttributeMappings(
        vararg
        values: Either<DynamicDeliveryAttributeMappingArgs, StaticDeliveryAttributeMappingArgs>,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deliveryAttributeMappings = mapped
    }

    /**
     * @param value Type of the endpoint for the event subscription destination.
     * Expected value is 'ServiceBusTopic'.
     */
    @JvmName("rqnyoimbtnsfdnmp")
    public suspend fun endpointType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpointType = mapped
    }

    /**
     * @param value The Azure Resource Id that represents the endpoint of the Service Bus Topic destination of an event subscription.
     */
    @JvmName("roinyvtgljxibtgw")
    public suspend fun resourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceId = mapped
    }

    internal fun build(): ServiceBusTopicEventSubscriptionDestinationArgs =
        ServiceBusTopicEventSubscriptionDestinationArgs(
            deliveryAttributeMappings = deliveryAttributeMappings,
            endpointType = endpointType ?: throw PulumiNullFieldException("endpointType"),
            resourceId = resourceId,
        )
}
